==> servicecatalog-model-6.2.0-sources.jar: io/fabric8/servicecatalog/api/model/BearerTokenAuthConfigFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BearerTokenAuthConfigFluentImpl<A extends BearerTokenAuthConfigFluent<A>> extends BaseFluent<A> implements BearerTokenAuthConfigFluent<A>{
  public BearerTokenAuthConfigFluentImpl() {
  }
  public BearerTokenAuthConfigFluentImpl(BearerTokenAuthConfig instance) {
    this.withSecretRef(instance.getSecretRef()); 
  }
  private LocalObjectReferenceBuilder secretRef;
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public LocalObjectReference buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public BearerTokenAuthConfigFluent.SecretRefNested<A> withNewSecretRef() {
    return new BearerTokenAuthConfigFluentImpl.SecretRefNestedImpl();
  }
  public BearerTokenAuthConfigFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item) {
    return new BearerTokenAuthConfigFluentImpl.SecretRefNestedImpl(item);
  }
  public BearerTokenAuthConfigFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public BearerTokenAuthConfigFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new LocalObjectReferenceBuilder().build());
  }
  public BearerTokenAuthConfigFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BearerTokenAuthConfigFluentImpl that = (BearerTokenAuthConfigFluentImpl) o;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends LocalObjectReferenceFluentImpl<BearerTokenAuthConfigFluent.SecretRefNested<N>> implements BearerTokenAuthConfigFluent.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) BearerTokenAuthConfigFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/BearerTokenAuthConfigFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BearerTokenAuthConfigFluentImpl<A extends BearerTokenAuthConfigFluent<A>> extends BaseFluent<A> implements BearerTokenAuthConfigFluent<A>{
  public BearerTokenAuthConfigFluentImpl() {
  }
  public BearerTokenAuthConfigFluentImpl(BearerTokenAuthConfig instance) {
    if (instance != null) {
      this.withSecretRef(instance.getSecretRef());
    }
  }
  private LocalObjectReferenceBuilder secretRef;
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public LocalObjectReference buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public BearerTokenAuthConfigFluentImpl.SecretRefNested<A> withNewSecretRef() {
    return new BearerTokenAuthConfigFluentImpl.SecretRefNestedImpl();
  }
  public BearerTokenAuthConfigFluentImpl.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item) {
    return new BearerTokenAuthConfigFluentImpl.SecretRefNestedImpl(item);
  }
  public BearerTokenAuthConfigFluentImpl.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public BearerTokenAuthConfigFluentImpl.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new LocalObjectReferenceBuilder().build());
  }
  public BearerTokenAuthConfigFluentImpl.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BearerTokenAuthConfigFluentImpl that = (BearerTokenAuthConfigFluentImpl) o;
    if (!java.util.Objects.equals(secretRef, that.secretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends LocalObjectReferenceFluentImpl<BearerTokenAuthConfigFluentImpl.SecretRefNested<N>> implements BearerTokenAuthConfigFluentImpl.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new LocalObjectReferenceBuilder(this);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) BearerTokenAuthConfigFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
